@@ -3,9 +3,9 @@ package jdk.internal.jshell.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "17.0.4.1+1" },
-            { "jdk", "17.0.4.1" },
-            { "release", "17.0.4.1" },
+            { "full", "17.0.8+7" },
+            { "jdk", "17.0.8" },
+            { "release", "17.0.8" },
         };
     }
 }
